Standard library for a JSON query language.
The standard library provides a set of filters.
These filters are either implemented as definitions or as functions.
For example, the standard library provides the map(f) filter,
which is defined using the more elementary filter [.[] | f].
Macros
- Convenience macro for
once_withwhich creates a closure and maps errors to exceptions.
Traits
- Values that the core library can operate on.
Functions
- Minimal set of filters that are generic over the value type. Return the minimal set of named filters available in jaq which are implemented as native filters, such as
length,keys, …, but notnow,debug,fromdateiso8601, … - Definitions of the standard library.
- Supplementary set of filters that are generic over the value type.
- Return those named filters available by default in jaq which are implemented as native filters, such as
length,keys, …, but alsonow,debug,fromdateiso8601, … - Return a boxed iterator that lazily evaluates the given function.
- Convert a filter with a run pointer to a native filter.
- Create a filter that takes a single variable argument and whose output is given by the function
fthat takes the input value and the value of the variable. - Creates
nvariable arguments.
Type Aliases
- Name, arguments, and implementation of a filter.